=============
API Reference
=============

The reference section contains documentation of Cloud's Sphinx extensions
and utility functions.

**Module list:**

.. toctree::
    :titlesonly:
    :maxdepth: 1

    cloud_sptheme
    cloud_sptheme.ext.index_styling
    cloud_sptheme.ext.relbar_toc
    cloud_sptheme.ext.relbar_links
    cloud_sptheme.ext.autodoc_sections
    cloud_sptheme.ext.autoattribute_search_bases
    cloud_sptheme.ext.docfield_markup
    cloud_sptheme.ext.issue_tracker
    cloud_sptheme.ext.escaped_samp_literals
    cloud_sptheme.ext.page_only
    cloud_sptheme.ext.role_index
    cloud_sptheme.ext.table_styling
    cloud_sptheme.ext.auto_redirect

..
    cloud_sptheme.make_helper
